@@ -65,7 +65,7 @@ func doUpdateKubeProxy(cmd *cmdutils.Cmd) error {
 		RawClient:           rawClient,
 		ControlPlaneVersion: kubernetesVersion,
 		Region:              meta.Region,
-		EKSAPI:              ctl.Provider.EKS(),
+		EKSAPI:              ctl.AWSProvider.EKS(),
 	}, cmd.Plan)
 	if err != nil {
 		return err
