@@ -1,7 +1,7 @@
 package eks_test
 
 import (
-	"github.com/aws/aws-sdk-go/aws"
+	"github.com/aws/aws-sdk-go-v2/aws"
 	. "github.com/onsi/ginkgo/v2"
 
 	. "github.com/onsi/gomega"
